@@ -3,9 +3,10 @@ from pathlib import Path
 
 from omegaconf import OmegaConf
 
-ROOT_DIR = Path(os.path.abspath(__file__)).parent.parent
+PKG_DIR = Path(os.path.abspath(__file__)).parent
+ROOT_DIR = PKG_DIR.parent
 if "DATA_DIR" not in os.environ:
     DATA_DIR = ROOT_DIR / "data"
 else:
     DATA_DIR = Path(os.environ["DATA_DIR"])
-DEFAULT_CONFIG = OmegaConf.load(ROOT_DIR / "grams.yaml")
+DEFAULT_CONFIG = OmegaConf.load(PKG_DIR / "grams.yaml")
